INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DELETEDQS','Deleted Qs','DELETEDQ','MIXED',1,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'2.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('9ACW','Croatian CW Contest','9A-CW','CW',2,'CountryPrefix','N/A',1,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ALLASIACW','All Asian DX contest CW','AADX-CW','CW',2,'WPXPrefix','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ALLASIASSB','All Asian DX contest SSB','AADX-SSB','SSB',2,'WPXPrefix','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('AGCW','AGCW Happy New Year','AG-CW','CW',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'2.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ANARTSRTTY','Anarts WW RTTY Contest','Anarts-RTTY','RTTY',2,'CountryPrefix','Sect',2,1,'Continent',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DRCGWWRTTY','German DRCG WW RTTY Contest','DRCG-WW-RTTY','RTTY',2,'CountryPrefix','Sect',2,1,'Continent',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ANATOLRTTY','Anatolian RTTY Contest','ANATOL-RTTY','RTTY',2,'CountryPrefix','Sect',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('APSCW','Asia Pacific Sprint CW','AP-Sprint-CW','CW',2,'WPXprefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('APSSSB','Asia Pacific Sprint SSB','AP-Sprint-SSB','SSB',2,'WPXprefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARCI','ARCI QRP Contest','ARCI','BOTH',3,'CountryPrefix','Sect',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARIDX','ARI DX INT','ARI-DX','BOTH',2,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRL10M','ARRL 10 Meter Contest','ARRL-10','Both',3,'StateProvince','CountryPrefix',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRLDXCW','ARRL DX CW','ARRL-DX-CW','CW',2,'CountryPrefix','N/A',2,3,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRLDXSSB','ARRL DX SSB','ARRL-DX-SSB','SSB',2,'CountryPrefix','N/A',2,3,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RRCW','ARRL Rookie Roundup - CW','ARRL-RR-CW','CW',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RRSSB','ARRL Rookie Roundup - SSB','ARRL-RR-SSB','SSB',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RRRTTY','ARRL Rookie Roundup - RTTY','ARRL-RR-RTTY','RTTY',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('FTROUNDUP','FT8/FT4 Roundup (AA5AU/W0YK, December)','FT8-RU','DIGITAL',2,'Sect','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRLRTTY','ARRL RTTY Roundup (January)','ARRL-RTTY','RTTY',2,'Sect','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('10MRTTY','10 Meter RTTY (AA5AU/W0YK, December)','TEN-RTTY','RTTY',2,'Sect','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRL-SCR','ARRL School RoundUp','ARRL-SCR','Both',3,'Sect','Mul',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SSCW','ARRL Sweepstakes CW (November)','ARRL-SS-CW','CW',1,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SSSSB','ARRL Sweepstakes SSB (November)','ARRL-SS-SSB','SSB',1,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRLVHFJAN','ARRL VHF Sweepstakes (January)','ARRL-VHF-JAN','BOTH',2,'GridSquare','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRLVHFJUN','ARRL VHF QSO Party (June)','ARRL-VHF-JUN','BOTH',2,'GridSquare','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRLVHFSEP','ARRL VHF QSO Party (September), ','ARRL-VHF-SEP','BOTH',2,'GridSquare','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQWWVHF','CQ WorldWide VHF (July)','CQ-VHF','BOTH',2,'GridSquare','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRLUHFAUG','ARRL UHF (August)','ARRL-UHF-AUG','BOTH',2,'GridSquare','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRL10GHZ','ARRL 10 GHZ & Up (August/Septebmer)','ARRL-10-GHZ','BOTH',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRL-222','ARRL 222 MHZ & Up Distance Contest','ARRL-222','BOTH',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRL160','ARRL 160 Meter Contest','ARRL-160','CW',2,'Sect','CountryPrefix',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ARRLIDC','ARRL International Digital Contest ','ARRL-DIGI','DIGITAL',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ASRUCHAMP','Asiatic Russia Championship','AS-CHAMP','BOTH',3,'Sect','MiscText',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('BALTIC','BALTIC','BALTIC-CONTEST','Both',3,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('BARTGSRTTY','BARTG HF RTTY (March, was Spring RTTY Contest)','BARTG-RTTY','RTTY',2,'CountryPrefix','Sect',2,1,'Continent',NULL,NULL,NULL,NULL,'2.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('BARTGRTTYS','BARTG RTTY Sprint contest (January)','BARTG-SPRINT','RTTY',2,'CountryPrefix','Sect',2,1,'Continent',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DMCRTTY','Digital Modes Club, DMC RTTY (July)','DMC-RTTY','RTTY',2,'CountryPrefix','Sect',2,1,'Continent',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('BAR75RTTYS','BARTG Sprint 75 Baud (April, September)','BARTG-SPRINT','RTTY',2,'CountryPrefix','Sect',2,1,'Continent',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('BARTGPSKS','BARTG Sprint PSK63 (December)','BARTG-PSK63','RTTY',2,'CountryPrefix','Sect',2,1,'Continent',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('BFRRCHCW','Belarus (only) CW Championship','BFRR-CHAMP-CW','CW',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('BFRRCHSSB','Belarus (only) SSB Championship','BFRR-CHAMP-SSB','SSB',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('BFRRCHMIX','Belarus Championship MIX','BFRR-CHAMP-MIX','BOTH',3,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('BSCI','Black Sea Cup International','BSCI-HF','Both',3,'CountryPrefix','Sect',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CISDXCW','CIS DX CW','CISDX-CW','CW',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CISDXSSB','CIS DX SSB','CISDX-SSB','SSB',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CISDXRTTY','CIS DX RTTY','CISDX-RTTY','RTTY',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CISDXQPSK','CIS QPSK63 DX','CIS-QPSK63-DX','RTTY',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CLARA','CLARA','CLARA','BOTH',3,'Sect','CountryPrefix',1,0,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CME','CME','CME','SSB',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CNCW','Spanish (only) contest - CW','CNCW','CW',3,'Sect','MiscText',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQ160CW','CQ World-Wide 160 Meter DX Contest - CW','CQ-160-CW','CW',1,'StateProvince','CountryPrefix',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQ160SSB','CQ World-Wide 160 Meter DX Contest - Phone','CQ-160-SSB','SSB',1,'StateProvince','CountryPrefix',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DIGCW','German Amateur Radio Club, DIG - CW','DIG-CW','CW',2,'Sect','CountryPrefix',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DIGSSB','DIG SSB','German Amateur Radio Club, DIG - Phone','CW',2,'Sect','CountryPrefix',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EARTTY','Spanish Radio Union, EA RTTY (April)','EA-RTTY','RTTY',2,'CountryPrefix','Sect',1,1,'MiscText',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EAPSK','Spanish Radio Union, EA PSK63 (March)','EA-PSK','RTTY',2,'CountryPrefix','Sect',1,1,'MiscText',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQM','CQ-M International DX contest (May)','CQ-M','BOTH',3,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQMMDX','CQ MM DX','CQMMDX','CW',2,'WPXPrefix','CountryPrefix',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQSASSB','CQ South America SSB Contest (October)','CQSA-SSB','SSB',2,'CountryPrefix','Continent',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQWPXRTTY','CQ WPX RTTY','CQ-WPX-RTTY','RTTY',2,'WPXPrefix','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQWPXCW','CQ WPX  CW','CQ-WPX-CW','CW',2,'WPXPrefix','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQWPXSSB','CQ WPX SSB','CQ-WPX-SSB','SSB',2,'WPXPrefix','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SASPRINT','SA SPRINT','SA-SPRINT','BOTH',3,'WPXPrefix','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CVADXCW','CVA DX CW','CVA-DX-CW','CW',2,'Sect','CountryPrefix',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CVADXSSB','CVA DX SSB','CVA-DX-SSB','SSB',2,'Sect','CountryPrefix',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DARC10M','German Amateur Radio Club, DARC 10 meter contest','DARC-10M','Both',2,'CountryPrefix','Sect',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DARC10MDIG','DARC 10M DIGI','DARC-10M-DIGI','RTTY',2,'CountryPrefix','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DLDXRTTY','German DL-DX RTTY contest (July)','DL-DX-RTTY','RTTY',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CWJFMM','CWJF MM','CWJF-MM','CW',2,'WPXPrefix','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CWOPS','CWops Mini-CWT Contest','CW-OPS','CW',2,'Callsign','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CWOPSOPEN','CWops CW Open Contest','CW-OPEN','CW',2,'Callsign','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('FOCBWQP','First Class Operators Club QSO Party','FOC-BWQP','CW',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DDFM50','French Amateur Radio, REF Depts, 50 MHz','DDFM50','BOTH',2,'GridSquare','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DRUZHBA','DRUZHBA','DRUZHBA','SSB',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DX','General Logging','DX','Both',3,'CountryPrefix','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DXSERIAL','General Serial','DXSerial','Both',3,'CountryPrefix','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DXPEDITION','DXPedition','DXPEDITION','Both',3,'CountryPrefix','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DXSATELLIT','DXSatellite','DXSATELLITE','Both',3,'CountryPrefix','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('VHFDX','General VHF logging','VHFDX','Both',3,'CountryPrefix','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('VHFSERIAL','VHF Serial logging','VHFSerial','Both',3,'CountryPrefix','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGBAFS-C','RSGB Affiliated Societies Contest - CW','RSGB-AFS-CW','CW',3,'N/A','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGBAFS-S','RSGB Affiliated Societies Contest - SSB','RSGB-AFS-SSB','SSB',3,'N/A','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGBCLUB','RSGB Club Calls','RSGB-CLUB-CALLS','Both',3,'Sect','Sect',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('MINITESTCW','Mini Test CW','Mini-Test-CW','CW',3,'Sect','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('MINITEST40','Mini Test CW/SSB','MINITEST-40','Both',3,'Sect','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('MINITEST80','Mini Test CW/SSB','MINITEST-80','Both',3,'Sect','N/A',32000,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EPCWWDX','EPC PSK WorldWide DX - PSK63','EPC-WW-DX','PSK',2,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EQSO','Elecraft QSO Party','EQSO','BOTH',3,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ECLIPSE','2023 Eclipse QSO Party','ECLIPSE-QSO','MIXED+DIG',3,'GridSquare','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EUPSKDX','European PSK DX contest (May)','EU-PSK-DX','PSK',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EPCPSK63QP','EPC PSK63 QSO Party (February)','EPC-PSK63','PSK',2,'MiscText','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EPCRUDX','EPC RU DX - PSK63','EPC-RU-DX','PSK',2,'CountryPrefix','GridSquare',1,1,'Sect',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EUSCW','European Sprint CW','EU-Sprint-CW','CW',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EUSSSB','European Sprint SSB','EU-Sprint-SSB','SSB',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EUHFC','European (only) HF Championship','EUHFC','Both',3,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('KVP','KVP(Slovenian)','KVP','Both',3,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('FD','ARRL Field Day (June)','ARRL-FIELD-DAY','Both',3,'N/A','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('WFD','Winter Field Day (January)','WFD','Both',3,'N/A','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NRRLNFD','NRRL Fieldday','NRRL-FIELDDAY','Both',3,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('FDREG1','Internatl Amateur Radio Union, Region 1 Field Day','FIELDDAY-REGION-1','Both',2,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('FMHPOC','Fox Mike Hotel Portable','POC','BOTH+DIG',3,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('FOCCW','First Class Operators Club Marathon - CW','FOC','CW',2,'CountryPrefix','Continent',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('GCUP','Yuri Gagarin International DX Contest','GC','CW',2,'Zone','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('HADX','Hungarian Amateur Radio DX contest','HA-DX','BOTH',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('HAMSPIRCW','Ham Spirit CW Contest','HAM-SPIRIT-CW','CW',3,'Zn','MiscText',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('HAMSPIRSSB','Ham Spirit SSB Contest','HAM-SPIRIT-SSB','SSB',3,'Zn','MiscText',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('HBC','HBC','HBC','Both',3,'Sect','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('HELVETIA','Helvetia','HELVETIA','Both',3,'CountryPrefix','Exchange1',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('HOLYLAND','NEW HOLYLAND DX (WWHC)','HOLYLAND-DX','BOTH',3,'Sect','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('HSCCW','High Speed CW Contest','HSC-CW','CW',2,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('IARU','Internatl Amateur Radio Union HF Contest','IARU-HF','Both',3,'ZN','HQ',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('IOTA','RSGB Islands On The Air Contest','RSGB-IOTA','Both',3,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('JADOMESTIC','Japan (only) domestic contest','JA-DOMESTIC','Both',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('JARTSWWRTY','Japan Amateur Radio TTY, WorldWide RTTY contest','JARTS-WW-RTTY','RTTY',2,'CountryPrefix','Sect',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('JIDXCW','Japan International DX Contest - CW','JIDX-CW','CW',2,'Sect','ZN',1,1,'CountryPrefix',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('JIDXSSB','Japan International DX Contest - SSB','JIDX-SSB','SSB',2,'Sect','ZN',1,1,'CountryPrefix',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('JTDX','Mongolian DX Contest','JT-DX','Both',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('JTDXRTTY','Mongolian DX Contest - RTTY','JT-DX-RTTY','RTTY',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('KINGEACW','King of Spain contest - CW','KING-OF-SPAIN-CW','CW',2,'Sect','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('KINGEASSB','King of Spain contest -SSB','KING-OF-SPAIN-SSB','SSB',2,'Sect','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('LOTWCW','Logbook Of The World CW Contest','LOTW-CW','CW',2,'StateProvince','CountryPrefix',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('LOTWSSB','Logbook Of The World SSB Contest','LOTW-SSB','SSB',2,'StateProvince','CountryPrefix',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('LOTWRTTY','Logbook Of The World RTTY Contest','LOTW-RTTY','RTTY',2,'StateProvince','CountryPrefix',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('LZDX','Bulgarian Federation DX contest','LZ-DX','Both',3,'Sect','IARU',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('MAKRORTTY','Makrothen RTTY (October)','MAKROTHEN-RTTY','RTTY',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NAQPCW','North American QSO Parties - CW','NAQP-CW','CW',2,'Sect','NA',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NAQPSSB','North American QSO Parties - SSB','NAQP-SSB','SSB',2,'Sect','NA',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NAQPRTTY','North American QSO Parties - RTTY','NAQP-RTTY','RTTY',2,'Sect','NA',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SPRINTSSB','North American Sprint - SSB','NA-SPRINT-SSB','SSB',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SPRINTLADD','NS with Same-Band Dupes Allowed','NS-SPRINT-CW','CW',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NSRTTYDUPE','NS RTTY with Same-Band Dupes Allowed','NS-SPRINT-RTTY','RTTY',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SPRINTNS','NS with No Same-Band Dupes Allowed','NS-SPRINT-CW','CW',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SPRINTCW','North American Sprint - CW','NA-SPRINT-CW','CW',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SPRINTRTTY','North American Sprint - RTTY','NA-SPRINT-RTTY','RTTY',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NAURYZDX','NAURYZDX','NAURYZDX','Both',3,'Sect','HQ',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NAVAL','International Naval contest','NAVAL','Both',3,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NRAUCW','Nordic Radio Amateur Union-Baltic - CW','NRAU-CW','CW',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NRAUSSB','Nordic Radio Amateur Union-Baltic - SSB','NRAU-SSB','SSB',2,'Sect','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NRAU10M','Nordic Radio Amateur Union-Baltic - 10 meters','NRAU-10M','BOTH',3,'Sect','CountryPrefix',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NRAUVHF','Nordic Radio Amateur Union-Baltic - VHF','NRAU-VHF','BOTH',3,'Sect','CountryPrefix',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NRRLVINTER','Norwegian Radio RL - Winter','NRRLVINTER','BOTH',3,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('NRRLFYLKE','Norwegian Radio RL - FYLKE','NRRLFYLKE','CW',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('OCEANIACW','Oceania DX  CW','Oceania-DX-CW','CW',2,'WPXPrefix','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('OCEANIASSB','Oceania DX SSB','Oceania-DX-SSB','SSB',2,'WPXPrefix','N/A',2,2,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('OKOMDX','Czech and Slovak Republics DX','OK-OM-DX','CW',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('OKDXRTTY','Czech Amateur Radio, OK DX RTTY','OK-DX-RTTY','RTTY',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('PABEKERSSB','Netherlands - PABEKER SSB','PABEKER-SSB','SSB',3,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('PABEKERCW','Netherlands - PABEKER CW','PABEKER-CW','CW',3,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('PACC','Netherlands - PACC','PACC','Both',3,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('PORTUGAL','Portugal Day contest','Portugal','BOTH',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('QCWAQSO','QCWAQSO','QCWAQSO','BOTH',3,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('QSOPARTY','QSO Parties (US and Canada)','QSO-PARTY','Both',3,'Exchange1','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RAC','RAC Canada Day and RAC Canada Winter contest','RAC-CANADA-DAY','Both',3,'Sect','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RAEM','RAEM (E.T.Krenkel contest)','RAEM','CW',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RDAC','Russian District Award Contest','RDAC','Both',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RCCCUP','RCC Cup','RCC-CUP','Both',3,'Sect','RCC',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('REFCW','French REF DX contest - CW','REF-CW','CW',2,'Sect','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('REFSSB','French REF DX contest - SSB','REF-SSB','SSB',2,'Sect','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('REGIOVHF','WANLC, VRZA - Netherland Locator Contest','NED-LOC','BOTH',2,'Gridsquare','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RFCCW','Cup of the Russian Federation - CW','RF-CUP-CW','CW',2,'Sect','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RFCSSB','Cup of the Russian Federation - SSB','RF-CUP-SSB','SSB',2,'Sect','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RFCDIGI','Russian Federation Digital contest','RFC-DIGI','BOTH',3,'Sect','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SRRCUPDIGI','SRR Cup Digital','SRR-CUP-DIGI','RTTY',2,'Sect','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('EUAS-CHAMP','Eurasia Championship','EURASIA-CHAMP','BOTH',3,'Sect','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RFCHAMPCW','Russion Federation (only) RF Championship CW','RF-Champ-CW','CW',2,'Sect','MiscText',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RFCHAMPSSB','Russion Federation (only) RF Championship SSB','RF-Champ-SSB','SSB',2,'Sect','MiscText',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SAMOVAR','SAMOVAR','SAMOVAR','CW',2,'Sect','MiscText',2,1,'CountryPrefix',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('DZCUP','UA1DZ Cup','Russian Memorial Cup ALRS-UA1DZ','Both',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('ROPOCO','RSGB ROLO','RSGB-ROLO','Both',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('LZOPEN','Bulgarian Federation Open and LZ Sprint','LZ-OPEN','CW',4,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('LZDOMESTIC','Bulgarian Federation Open Domestic','LZ-OPEN-DOMESTIC','Both',4,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('LZFIELD60','LZ FIELD60','LZ-FIELD60','CW',4,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('LZBALCHIK','Balchik-Waves-Friends contest','LZBALCHIK','Both',4,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RRTC','Russian Radiosport Team Championship','RRTC','Both',3,'Sect','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RRTCT','Russian Radiosport Team Championship (July)','RRTC','Both',3,'CountryPrefix','N/A',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGB80MCC','RSGB 80M CC','RSGB-80M-CC','Both',3,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGB160CW','RSGB 160 CW','RSGB-1.8-CW','CW',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGB1ST160','RSGB 160 1-st','RSGB-1st1.8','BOTH',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGB2ND160','RSGB 160 2-nd','RSGB-2nd1.8','CW',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGB2128','RSGB 21/28 MHz','RSGB-21/28','Both',3,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGBDX','RSGB International DX','RSGB-DX','Both',3,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGBLP','RSGB Low Power','RSGB-LOW-POWER','CW',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RSGBBERU','RSGB Commonwealth (only) contest','RSGB-BERU','CW',2,'CountryPrefix','Sect',1,5,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RUSSIANDX','Russian DX','RDXC','Both',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RUSDXRTTY','Russian DX RTTY','RADIO-WW-RTTY','RTTY',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RUSDXPSK','Russian DX PSK','RUS-DX-PSK','RTTY',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('KPC','KULIKOVO POLYE','KPC','CW',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RUS-WW-MM','RUS WW MM','RUS-WW-MM','BOTH',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RUS-WW-DIG','RUS WW DIGI','RUS-WW-DIGI','RTTY',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RUS-WW-PSK','Russian WW PSK','RUS-WW-PSK','RTTY',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RUCUPRTTY','Cup of the Russian Federation - RTTY','RUCup RTTY','RTTY',2,'Sect','MiscText',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RUSYLOM','Russian YL OM','RUSSIAN-YL-OM','BOTH',3,'N/A','N/A',1,0,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('MOROZ','MOROZ QRP','MOROZ','BOTH',1,'N/A','N/A',1,0,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('RUSFIELD','Russkoje Pole QRP','RF','BOTH',1,'N/A','N/A',1,0,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SACCW','Scandinavian Activity Contest, SAC - CW','SAC-CW','CW',2,'CountryPrefix','N/A',2,3,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SACSSB','Scandinavian Activity Contest, SAC - SSB','SAC-SSB','SSB',2,'CountryPrefix','N/A',2,3,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SPDX','SP, Polish Amateur Radio - DX contest','SP-DX','Both',3,'CountryPrefix','N/A',1,3,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SPDXRTTY','SP, Polish Amateur Radio - DX RTTY','SP-DX-RTTY','RTTY',3,'CountryPrefix','Sect',1,3,'Continent',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SARTGNYRTY','Scandinavian Amateur Radio, SARTG New Year RTTY','SARTG-NY-RTTY','RTTY',2,'CountryPrefix','WPXPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SARTGRTTY','Scandinavian Amateur Radio, WorldWide RTTY','SARTG-RTTY','RTTY',2,'CountryPrefix','Sect',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SCCRTTY','Slovenia Contest Club, SCC - RTTY','SCC-RTTY','RTTY',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SCRY','Scandinavian Baltic RTTY','SCRY','RTTY',2,'Sect','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('STEWPERRY','Stew Perry 160 meter','STEW-PERRY','CW',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('SYLRA','Scandinavian YL - SYLRA','SYLRA','BOTH',3,'CountryPrefix','N/A',1,0,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('TARAPSK','Troy Amateur Radio Association, TARA PSK Rumble','TARAPSKR','PSK',2,'CountryPrefix','Section',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('TARAGRID','Troy Amateur Radio Association, TARA Grid Dip','TARA_GRID_DIP','BOTH',2,'GridSquare','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('TARARTTY','Troy Amateur Radio Association, TARA RTTY Melee','TARARTTY','RTTY',2,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('TRCDX','Bulgaria, Thracian Rose Club - TRCDX','TRCDX','Both',3,'CountryPrefix','CountryPrefix',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('TRCDIGI','Bulgaria, Thracian Rose Club - TRC DIGI','TRC-DIGI','RTTY',3,'CountryPrefix','CountryPrefix',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UA2QP','UA2 QSO Party','UA2-QP','Both',3,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UBACW','Belgium Amateur Radio, UBA DX - CW','UBA-DX-CW','CW',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UBASSB','Belgium Amateur Radio, UBA DX - SSB','UBA-DX-SSB','SSB',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UBAON','Belgium Amateur Radio, UBA ON','UBA-ON','BOTH',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UBASPRING','Belgium Amateur Radio, UBA Spring','UBA-SPRING','BOTH',2,'Sect','CountryPrefix',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKEIDXCW','United Kingdon and Irelend - DX CW','UKEIDX-CW','CW',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKEIDXSSB','United Kingdon and Irelend - DX SSB','UKEIDX-SSB','SSB',2,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKRAINDX','UKRAINIAN DX','UKRAINIAN-DX','BOTH',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKRAINDIGI','UKRAINIAN DIGI','UKRAINIAN-DIGI','BOTH',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKRAINRTTY','UKRAINIAN DIGI','UKRAINIAN-DIGI','BOTH',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKRCHRTTY','Ukrainian Championship - RTTY','UKR-CHAMP-RTTY','RTTY',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKRCHCW','Ukrainian Championship - CW','UKR-CHAMP-CW','CW',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKRCHSSB','Ukrainian Championship - SSB','UKR-CHAMP-SSB','SSB',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKRRTTYOPN','Ukrainian Championship - RTTY OPEN','UKR-CHAMP-RTTY','RTTY',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKRCUPLP','Ukrainian Cup LP','UKR-CUP-LP','CW',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UKSMG','UKSMG 50 MHz Summer','UKSMG','BOTH',2,'CountryPrefix','GridSquare',1,1,'Comment',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('UNDX','Kazakhstan Fed of Radiosport - UN DX','UN DX Contest','Both',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('VHFREG1','VHF Region 1','VHF-REG-1','BOTH',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('VHFHGOB','VHF HB OB','VHF-HB-OB','BOTH',3,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('VHFNAC','Nordic Amateur Radio - VHF Activity','NAC','BOTH',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('VHFHELV26','VHF Helvetia 26','VHF-HELVETIA-26','BOTH',2,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('VHFCFO','VHF CFO','VHF-CFO','BOTH',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('VHFDZCUP','VHF UA1DZ CUP','VHF-DZCUP','BOTH',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('VOLTARTTY','Volta RTTY Contest','VOLTA-RTTY','RTTY',2,'CountryPrefix','Sect',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('WAECW','Worked All Europe - WAE CW','DARC-WAEDC-CW','CW',3,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('WAESSB','Worked All Europe - WAE SSB','DARC-WAEDC-SSB','SSB',3,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('WAERTTY','Worked All Europe - WAE RTTY','DARC-WAEDC-RTTY','RTTY',3,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('WAG','Worked All Germany contest','WAG','BOTH',3,'CountryPrefix','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('XERTTY','Mexico RTTY Contest','XE-RTTY','RTTY',2,'Countryprefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('XMAS','German Amateur Radio Club, DARC - Christmas','XMAS','BOTH',2,'WPXprefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('WWDIGI','World Wide Digi DX ','WW-DIGI','DIGITAL',2,'N/A','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('WWPMC','World Wide Peace Messenger Contest','WWPMC','Both',3,'Sect','N/A',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('WWIH','WorldWide Iron Ham','WW-IH','BOTH',3,'CountryPrefix','ZN',1,3,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('WRTC','World Radiosport Team Championship - WRTC','IARU-HF','Both',3,'Cty','HQ',2,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('YOHFDX','Romanian Amateur Radio Federation - YO DX HF','YO-DX-HF','Both',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('YUDX','Serbia Amateur Radio Union, YU DX','YU-DX','Both',3,'CountryPrefix','Exchange1',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('YV','Independence of Venezuela Contest','YV','Both',3,'CountryPrefix','Sect',1,1,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQWWCW','CQ WorldWide CW','CQ-WW-CW','CW',2,'ZN','CountryPrefix',2,3,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQWWSSB','CQ WorldWide SSB','CQ-WW-SSB','SSB',2,'ZN','CountryPrefix',2,3,'N/A',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('CQWWRTTY','CQ WorldWide RTTY','CQ-WW-RTTY','RTTY',2,'ZN','CountryPrefix',2,3,'Sect',NULL,NULL,NULL,NULL,'3.0');
INSERT INTO "Contest" ("Name","DisplayName","CabrilloName","Mode","DupeType","Multiplier1Name","Multiplier2Name","Period","PointsPerContact","Multiplier3Name","MasterDTA","CWMessages","SSBMessages","DigiMessages","CabrilloVersion") VALUES ('GACW','WorldWide South America DX contest - CW','GACW','CW',2,'ZN','CountryPrefix',2,3,'N/A',NULL,NULL,NULL,NULL,'3.0');
